@@ -40,6 +40,7 @@
 #include <libempathy/empathy-debug.h>
 
 #define IRC_NETWORKS_FILENAME "irc-networks.xml"
+#define DEFAULT_IRC_NETWORK "irc.gimp.org"
 
 typedef struct {
   EmpathyAccountWidget *self;
@@ -414,8 +415,14 @@ account_widget_irc_setup (EmpathyAccountWidgetIrc *settings)
         }
     }
 
+  if (network == NULL)
+    {
+      network = empathy_irc_network_manager_find_network_by_address (
+          settings->network_manager, DEFAULT_IRC_NETWORK);
+    }
 
   fill_networks_model (settings, network);
+  update_server_params (settings);
 }
 
 void
@@ -437,7 +444,7 @@ empathy_account_widget_irc_build (EmpathyAccountWidget *self,
   g_free (dir);
 
   global_file_with_path = g_build_filename (g_getenv ("EMPATHY_SRCDIR"),
-      "libempathy-gtk", IRC_NETWORKS_FILENAME, NULL);
+      "libempathy", IRC_NETWORKS_FILENAME, NULL);
   if (!g_file_test (global_file_with_path, G_FILE_TEST_EXISTS))
     {
       g_free (global_file_with_path);
