@@ -31,7 +31,7 @@
 #include <glib/gi18n-lib.h>
 
 #ifdef HAVE_MEEGO
-#include <mx/mx-gtk.h>
+#include <mx-gtk/mx-gtk.h>
 #endif /* HAVE_MEEGO */
 
 #include <libempathy/empathy-utils.h>
@@ -600,6 +600,7 @@ accounts_widget_generic_setup (EmpathyAccountWidget *self,
             case 't': minint = 0;          maxint = G_MAXUINT64; break;
             case 'd': minint = G_MININT32; maxint = G_MAXINT32;
               step = 0.1; break;
+            default: g_assert_not_reached ();
             }
 
           str = g_strdup_printf (_("%s:"), param_name_formatted);
@@ -1361,7 +1362,7 @@ account_widget_switch_flipped_cb (MxGtkLightSwitch *sw,
     gboolean state,
     gpointer user_data)
 #else
-account_widget_enabled_released_cb (GtkToggleButton *toggle_button,
+account_widget_enabled_toggled_cb (GtkToggleButton *toggle_button,
     gpointer user_data)
 #endif /* HAVE_MEEGO */
 {
@@ -1587,8 +1588,8 @@ add_enable_checkbox (EmpathyAccountWidget *self,
   g_signal_connect (G_OBJECT (priv->enabled_checkbox), "switch-flipped",
       G_CALLBACK (account_widget_switch_flipped_cb), self);
 #else
-  g_signal_connect (G_OBJECT (priv->enabled_checkbox), "released",
-      G_CALLBACK (account_widget_enabled_released_cb), self);
+  g_signal_connect (G_OBJECT (priv->enabled_checkbox), "toggled",
+      G_CALLBACK (account_widget_enabled_toggled_cb), self);
 #endif /* HAVE_MEEGO */
 }
 
