@@ -228,18 +228,11 @@ chat_set_property (GObject      *object,
 }
 
 static void
-reconnected_connection_ready_cb (TpConnection *connection,
-			const GError *error,
-			gpointer user_data)
+account_reconnected (EmpathyChat *chat,
+			TpAccount *account)
 {
-	EmpathyChat *chat = user_data;
 	EmpathyChatPriv *priv = GET_PRIV (chat);
 
-	if (error != NULL) {
-		DEBUG ("connection is not ready: %s", error->message);
-		goto out;
-	}
-
 	DEBUG ("Account reconnected, request a new Text channel");
 
 	/* FIXME: Ideally we should ask to handle ourself the channel so we can
@@ -248,19 +241,20 @@ reconnected_connection_ready_cb (TpConnection *connection,
 	switch (priv->handle_type) {
 		case TP_HANDLE_TYPE_CONTACT:
 			empathy_dispatcher_chat_with_contact_id (
-				connection, priv->id, EMPATHY_DISPATCHER_NON_USER_ACTION,
-				NULL, NULL);
+				account, priv->id, TP_USER_ACTION_TIME_NOT_USER_ACTION);
 			break;
 		case TP_HANDLE_TYPE_ROOM:
-			empathy_dispatcher_join_muc (connection,
-				priv->id, EMPATHY_DISPATCHER_NON_USER_ACTION);
+			empathy_dispatcher_join_muc (account, priv->id,
+				TP_USER_ACTION_TIME_NOT_USER_ACTION);
 			break;
+		case TP_HANDLE_TYPE_NONE:
+		case TP_HANDLE_TYPE_LIST:
+		case TP_HANDLE_TYPE_GROUP:
 		default:
 			g_assert_not_reached ();
 			break;
 	}
 
-out:
 	g_object_unref (chat);
 }
 
@@ -287,8 +281,8 @@ chat_new_connection_cb (TpAccount   *account,
 		return;
 
 	g_object_ref (chat);
-	tp_connection_call_when_ready (connection, reconnected_connection_ready_cb,
-				   chat);
+
+	account_reconnected (chat, account);
 }
 
 static void
@@ -716,8 +710,8 @@ chat_command_join (EmpathyChat *chat,
 			TpConnection *connection;
 
 			connection = empathy_tp_chat_get_connection (priv->tp_chat);
-			empathy_dispatcher_join_muc (connection, rooms[i],
-						     gtk_get_current_event_time ());
+			empathy_dispatcher_join_muc (priv->account, rooms[i],
+				gtk_get_current_event_time ());
 		}
 		i++;
 	}
@@ -1166,6 +1160,7 @@ chat_send_error_cb (EmpathyTpChat          *tp_chat,
 	case TP_CHANNEL_TEXT_SEND_ERROR_NOT_IMPLEMENTED:
 		error = _("not implemented");
 		break;
+	case TP_CHANNEL_TEXT_SEND_ERROR_UNKNOWN:
 	default:
 		error = _("unknown");
 		break;
@@ -3017,7 +3012,7 @@ empathy_chat_set_tp_chat (EmpathyChat   *chat,
 
 	priv->tp_chat = g_object_ref (tp_chat);
 	connection = empathy_tp_chat_get_connection (priv->tp_chat);
-	priv->account = g_object_ref (empathy_get_account_for_connection (connection));
+	priv->account = g_object_ref (empathy_tp_chat_get_account (priv->tp_chat));
 
 	g_signal_connect (tp_chat, "destroy",
 			  G_CALLBACK (chat_destroy_cb),
