@@ -33,7 +33,6 @@
 #include <libempathy/empathy-utils.h>
 #include "empathy-theme-boxes.h"
 #include "empathy-ui-utils.h"
-#include "empathy-conf.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include <libempathy/empathy-debug.h>
@@ -41,10 +40,12 @@
 #define MARGIN 4
 #define HEADER_PADDING 2
 
+/* "Join" consecutive messages with timestamps within five minutes */
+#define MESSAGE_JOIN_PERIOD 5*60
+
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyThemeBoxes)
 typedef struct {
 	gboolean show_avatars;
-	guint    notify_show_avatars_id;
 } EmpathyThemeBoxesPriv;
 
 G_DEFINE_TYPE (EmpathyThemeBoxes, empathy_theme_boxes, EMPATHY_TYPE_CHAT_TEXT_VIEW);
@@ -200,18 +201,23 @@ theme_boxes_maybe_append_header (EmpathyThemeBoxes *theme,
 	GtkTextTagTable      *table;
 	GtkTextTag           *tag;
 	GString              *str_obj;
+	gboolean              consecutive;
 
 	contact = empathy_message_get_sender (msg);
-	name = empathy_contact_get_name (contact);
+	name = empathy_contact_get_alias (contact);
 	last_contact = empathy_chat_text_view_get_last_contact (view);
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (theme));
+	time_ = empathy_message_get_timestamp (msg);
+	consecutive = (time_ - empathy_chat_text_view_get_last_timestamp (view)
+		< MESSAGE_JOIN_PERIOD);
 
 	DEBUG ("Maybe add fancy header");
 
-	/* Only insert a header if the previously inserted block is not the same
-	 * as this one.
+	/* Only insert a header if
+	 *   - the previously inserted block is not the same as this one.
+	 *   - the delay between two messages is lower then MESSAGE_JOIN_PERIOD
 	 */
-	if (empathy_contact_equal (last_contact, contact)) {
+	if (empathy_contact_equal (last_contact, contact) && consecutive) {
 		return;
 	}
 
@@ -259,7 +265,6 @@ theme_boxes_maybe_append_header (EmpathyThemeBoxes *theme,
 	g_free (str);
 
 	/* Add the message receive time */
-	time_ = empathy_message_get_timestamp (msg);
 	tmp = empathy_time_to_string_local (time_,
 					   EMPATHY_TIME_FORMAT_DISPLAY_SHORT);
 	str = g_strdup_printf ("<i>%s</i>", tmp);
@@ -342,7 +347,7 @@ theme_boxes_append_message (EmpathyChatTextView *view,
 		gchar *body;
 
 		body = g_strdup_printf (" * %s %s",
-					empathy_contact_get_name (sender),
+					empathy_contact_get_alias (sender),
 					empathy_message_get_body (message));
 		empathy_chat_text_view_append_body (EMPATHY_CHAT_TEXT_VIEW (view),
 						    body,
@@ -354,27 +359,6 @@ theme_boxes_append_message (EmpathyChatTextView *view,
 	}
 }
 
-static void
-theme_boxes_notify_show_avatars_cb (EmpathyConf *conf,
-				    const gchar *key,
-				    gpointer     user_data)
-{
-	EmpathyThemeBoxesPriv *priv = GET_PRIV (user_data);
-
-	empathy_conf_get_bool (conf, key, &priv->show_avatars);
-}
-
-static void
-theme_boxes_finalize (GObject *object)
-{
-	EmpathyThemeBoxesPriv *priv = GET_PRIV (object);
-
-	empathy_conf_notify_remove (empathy_conf_get (),
-				    priv->notify_show_avatars_id);
-
-	G_OBJECT_CLASS (empathy_theme_boxes_parent_class)->finalize (object);
-}
-
 static void
 empathy_theme_boxes_class_init (EmpathyThemeBoxesClass *class)
 {
@@ -384,7 +368,6 @@ empathy_theme_boxes_class_init (EmpathyThemeBoxesClass *class)
 	object_class = G_OBJECT_CLASS (class);
 	chat_text_view_class  = EMPATHY_CHAT_TEXT_VIEW_CLASS (class);
 
-	object_class->finalize = theme_boxes_finalize;
 	chat_text_view_class->append_message = theme_boxes_append_message;
 
 	g_type_class_add_private (object_class, sizeof (EmpathyThemeBoxesPriv));
@@ -398,18 +381,12 @@ empathy_theme_boxes_init (EmpathyThemeBoxes *theme)
 
 	theme->priv = priv;
 
+	/* This is just hard-coded to TRUE until someone adds a tickybox in the
+	 * Theme tab for it. */
+	priv->show_avatars = TRUE;
+
 	theme_boxes_create_tags (theme);
 
-	priv->notify_show_avatars_id =
-		empathy_conf_notify_add (empathy_conf_get (),
-					 EMPATHY_PREFS_UI_SHOW_AVATARS,
-					 theme_boxes_notify_show_avatars_cb,
-					 theme);
-
-	empathy_conf_get_bool (empathy_conf_get (),
-			       EMPATHY_PREFS_UI_SHOW_AVATARS,
-			       &priv->show_avatars);
-
 	/* Define margin */
 	g_object_set (theme,
 		      "left-margin", MARGIN,
