@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2002-2007 Imendio AB
- * Copyright (C) 2007-2008 Collabora Ltd.
+ * Copyright (C) 2007-2010 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,6 +23,7 @@
  *          Martyn Russell <martyn@imendio.com>
  *          Xavier Claessens <xclaesse@gmail.com>
  *          Jonny Lamb <jonny.lamb@collabora.co.uk>
+ *          Travis Reitter <travis.reitter@collabora.co.uk>
  *
  *          Part of this file is copied from GtkSourceView (gtksourceiter.c):
  *          Paolo Maggi
@@ -34,6 +35,8 @@
 
 #include <gtk/gtk.h>
 
+#include <folks/folks.h>
+
 #include <libempathy/empathy-contact.h>
 #include <libempathy/empathy-ft-handler.h>
 
@@ -46,6 +49,10 @@ G_BEGIN_DECLS
 					    (x) < gdk_screen_width () && \
 					    (y) < gdk_screen_height ())
 
+typedef void (*EmpathyPixbufAvatarFromIndividualCb) (FolksIndividual *individual,
+		GdkPixbuf *pixbuf,
+		gpointer user_data);
+
 void            empathy_gtk_init                        (void);
 
 /* Glade */
@@ -54,7 +61,7 @@ GtkBuilder *    empathy_builder_get_file                (const gchar      *filen
 							 ...);
 void            empathy_builder_connect                 (GtkBuilder       *gui,
 							 gpointer          user_data,
-							 gchar            *first_object,
+							 const gchar      *first_object,
 							 ...);
 GtkWidget     *empathy_builder_unref_and_keep_widget    (GtkBuilder       *gui,
 							 GtkWidget        *root);
@@ -62,12 +69,22 @@ GtkWidget     *empathy_builder_unref_and_keep_widget    (GtkBuilder       *gui,
 /* Pixbufs */
 const gchar * empathy_icon_name_for_presence            (TpConnectionPresenceType  presence);
 const gchar * empathy_icon_name_for_contact             (EmpathyContact   *contact);
+const gchar * empathy_icon_name_for_individual          (FolksIndividual  *individual);
 const gchar * empathy_protocol_name_for_contact         (EmpathyContact   *contact);
 GdkPixbuf *   empathy_pixbuf_from_data                  (gchar            *data,
 							 gsize             data_size);
 GdkPixbuf *   empathy_pixbuf_from_data_and_mime         (gchar            *data,
 							 gsize             data_size,
 							 gchar           **mime_type);
+void empathy_pixbuf_avatar_from_individual_scaled_async (FolksIndividual     *individual,
+							 GAsyncReadyCallback  callback,
+							 gint                 width,
+							 gint                 height,
+							 gpointer             user_data);
+GdkPixbuf * empathy_pixbuf_avatar_from_individual_scaled_finish (
+							 FolksIndividual  *individual,
+							 GAsyncResult     *result,
+							 GError          **error);
 GdkPixbuf *   empathy_pixbuf_from_avatar_scaled         (EmpathyAvatar    *avatar,
 							 gint              width,
 							 gint              height);
@@ -104,7 +121,9 @@ gboolean    empathy_text_iter_backward_search           (const GtkTextIter*iter,
 							 const GtkTextIter*limit);
 /* Windows */
 gboolean    empathy_window_get_is_visible               (GtkWindow        *window);
-void        empathy_window_present                      (GtkWindow        *window);
+void        empathy_window_present                      (GtkWindow *window);
+void        empathy_window_present_with_time            (GtkWindow        *window,
+							 guint32 timestamp);
 void        empathy_window_iconify                      (GtkWindow        *window,
 							 GtkStatusIcon    *status_icon);
 GtkWindow * empathy_get_toplevel_window                 (GtkWidget        *widget);
@@ -116,8 +135,6 @@ gchar *     empathy_make_absolute_url_len               (const gchar      *url,
 							 guint             len);
 void        empathy_url_show                            (GtkWidget        *parent,
 							 const char       *url);
-GtkWidget * empathy_link_button_new                     (const gchar      *url,
-							 const gchar      *title);
 
 /* File transfer */
 void        empathy_send_file                           (EmpathyContact   *contact,
