@@ -32,7 +32,7 @@
 #include <folks/folks.h>
 #include <folks/folks-telepathy.h>
 
-#if HAVE_GEOCLUE
+#ifdef HAVE_GEOCLUE
 #include <geoclue/geoclue-geocode.h>
 #endif
 
@@ -75,7 +75,7 @@ static void contact_get_property (GObject *object, guint param_id,
 static void contact_set_property (GObject *object, guint param_id,
     const GValue *value, GParamSpec *pspec);
 
-#if HAVE_GEOCLUE
+#ifdef HAVE_GEOCLUE
 static void update_geocode (EmpathyContact *contact);
 #endif
 
@@ -502,7 +502,7 @@ contact_set_property (GObject *object,
     };
 }
 
-EmpathyContact *
+static EmpathyContact *
 empathy_contact_new (TpContact *tp_contact)
 {
   g_return_val_if_fail (TP_IS_CONTACT (tp_contact), NULL);
@@ -807,7 +807,8 @@ empathy_contact_get_persona (EmpathyContact *contact)
                   if (tp_contact == priv->tp_contact)
                     {
                       /* Found the right persona */
-                      priv->persona = g_object_ref (persona);
+                      empathy_contact_set_persona (contact,
+                          (FolksPersona *) persona);
                       goto finished;
                     }
                 }
@@ -848,7 +849,8 @@ empathy_contact_set_persona (EmpathyContact *contact,
   /* Set the persona's alias, since ours could've been set using
    * empathy_contact_set_alias() before we had a persona; this happens when
    * adding a contact. */
-  empathy_contact_set_alias (contact, priv->alias);
+  if (priv->alias != NULL)
+    empathy_contact_set_alias (contact, priv->alias);
 
   /* Set the persona's groups */
   if (priv->groups != NULL)
@@ -1046,7 +1048,13 @@ empathy_contact_is_online (EmpathyContact *contact)
       case TP_CONNECTION_PRESENCE_TYPE_OFFLINE:
       case TP_CONNECTION_PRESENCE_TYPE_UNKNOWN:
       case TP_CONNECTION_PRESENCE_TYPE_ERROR:
+      case TP_CONNECTION_PRESENCE_TYPE_UNSET:
         return FALSE;
+      case TP_CONNECTION_PRESENCE_TYPE_AVAILABLE:
+      case TP_CONNECTION_PRESENCE_TYPE_AWAY:
+      case TP_CONNECTION_PRESENCE_TYPE_EXTENDED_AWAY:
+      case TP_CONNECTION_PRESENCE_TYPE_HIDDEN:
+      case TP_CONNECTION_PRESENCE_TYPE_BUSY:
       default:
         return TRUE;
     }
@@ -1347,7 +1355,7 @@ empathy_contact_set_location (EmpathyContact *contact,
     g_hash_table_unref (priv->location);
 
   priv->location = g_hash_table_ref (location);
-#if HAVE_GEOCLUE
+#ifdef HAVE_GEOCLUE
   update_geocode (contact);
 #endif
   g_object_notify (G_OBJECT (contact), "location");
@@ -1390,7 +1398,7 @@ empathy_contact_equal (gconstpointer contact1,
   return FALSE;
 }
 
-#if HAVE_GEOCLUE
+#ifdef HAVE_GEOCLUE
 #define GEOCODE_SERVICE "org.freedesktop.Geoclue.Providers.Yahoo"
 #define GEOCODE_PATH "/org/freedesktop/Geoclue/Providers/Yahoo"
 
