@@ -26,9 +26,8 @@
 
 #include <telepathy-glib/contact.h>
 #include <telepathy-glib/account.h>
-#ifdef ENABLE_TPL
-#include <telepathy-logger/contact.h>
-#endif /* ENABLE_TPL */
+#include <telepathy-logger/entity.h>
+#include <folks/folks.h>
 
 G_BEGIN_DECLS
 
@@ -67,27 +66,29 @@ typedef enum {
   EMPATHY_CAPABILITIES_AUDIO = 1 << 0,
   EMPATHY_CAPABILITIES_VIDEO = 1 << 1,
   EMPATHY_CAPABILITIES_FT = 1 << 2,
-  EMPATHY_CAPABILITIES_STREAM_TUBE = 1 << 3,
+  EMPATHY_CAPABILITIES_RFB_STREAM_TUBE = 1 << 3,
   EMPATHY_CAPABILITIES_UNKNOWN = 1 << 7
 } EmpathyCapabilities;
 
 GType empathy_contact_get_type (void) G_GNUC_CONST;
-EmpathyContact * empathy_contact_new (TpContact *tp_contact);
-#ifdef ENABLE_TPL
 EmpathyContact * empathy_contact_from_tpl_contact (TpAccount *account,
-    TplContact *tpl_contact);
-#endif /* ENABLE_TPL */
+    TplEntity *tpl_contact);
 EmpathyContact * empathy_contact_new_for_log (TpAccount *account,
-    const gchar *id, const gchar *name, gboolean is_user);
+    const gchar *id, const gchar *alias, gboolean is_user);
 TpContact * empathy_contact_get_tp_contact (EmpathyContact *contact);
 const gchar * empathy_contact_get_id (EmpathyContact *contact);
 void empathy_contact_set_id (EmpathyContact *contact, const gchar *id);
-const gchar * empathy_contact_get_name (EmpathyContact *contact);
-void empathy_contact_set_name (EmpathyContact *contact, const gchar *name);
+const gchar * empathy_contact_get_alias (EmpathyContact *contact);
+void empathy_contact_set_alias (EmpathyContact *contact, const gchar *alias);
+void empathy_contact_change_group (EmpathyContact *contact, const gchar *group,
+    gboolean is_member);
 EmpathyAvatar * empathy_contact_get_avatar (EmpathyContact *contact);
 void empathy_contact_set_avatar (EmpathyContact *contact,
     EmpathyAvatar *avatar);
 TpAccount * empathy_contact_get_account (EmpathyContact *contact);
+FolksPersona * empathy_contact_get_persona (EmpathyContact *contact);
+void empathy_contact_set_persona (EmpathyContact *contact,
+    FolksPersona *persona);
 TpConnection * empathy_contact_get_connection (EmpathyContact *contact);
 TpConnectionPresenceType empathy_contact_get_presence (EmpathyContact *contact);
 void empathy_contact_set_presence (EmpathyContact *contact,
@@ -109,11 +110,7 @@ gboolean empathy_contact_can_voip (EmpathyContact *contact);
 gboolean empathy_contact_can_voip_audio (EmpathyContact *contact);
 gboolean empathy_contact_can_voip_video (EmpathyContact *contact);
 gboolean empathy_contact_can_send_files (EmpathyContact *contact);
-gboolean empathy_contact_can_use_stream_tube (EmpathyContact *contact);
-
-void empathy_contact_load_avatar_data (EmpathyContact *contact,
-    const guchar *data, const gsize len, const gchar *format,
-    const gchar *token);
+gboolean empathy_contact_can_use_rfb_stream_tube (EmpathyContact *contact);
 gboolean empathy_contact_load_avatar_cache (EmpathyContact *contact,
     const gchar *token);
 
@@ -132,11 +129,11 @@ gboolean empathy_avatar_save_to_file (EmpathyAvatar *avatar,
     const gchar *filename, GError **error);
 
 GHashTable * empathy_contact_get_location (EmpathyContact *contact);
-void empathy_contact_set_location (EmpathyContact *contact,
-    GHashTable *location);
 gboolean empathy_contact_equal (gconstpointer contact1,
     gconstpointer contact2);
 
+EmpathyContact *empathy_contact_dup_from_tp_contact (TpContact *tp_contact);
+
 G_END_DECLS
 
 #endif /* __EMPATHY_CONTACT_H__ */
