@@ -530,7 +530,7 @@ empathy_message_should_highlight (EmpathyMessage *message)
 		return FALSE;
 	}
 
-	to = empathy_contact_get_name (contact);
+	to = empathy_contact_get_alias (contact);
 	if (!to) {
 		return FALSE;
 	}
@@ -603,6 +603,9 @@ empathy_message_type_to_str (TpChannelTextMessageType type)
 		return "notice";
 	case TP_CHANNEL_TEXT_MESSAGE_TYPE_AUTO_REPLY:
 		return "auto-reply";
+	case TP_CHANNEL_TEXT_MESSAGE_TYPE_DELIVERY_REPORT:
+		return "delivery-report";
+	case TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL:
 	default:
 		return "normal";
 	}
