@@ -41,6 +41,7 @@
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyTpChat)
 typedef struct {
 	gboolean               dispose_has_run;
+	TpAccount             *account;
 	TpConnection          *connection;
 	EmpathyContact        *user;
 	EmpathyContact        *remote_contact;
@@ -65,6 +66,7 @@ static void tp_chat_iface_init         (EmpathyContactListIface *iface);
 
 enum {
 	PROP_0,
+	PROP_ACCOUNT,
 	PROP_CHANNEL,
 	PROP_REMOTE_CONTACT,
 	PROP_PASSWORD_NEEDED,
@@ -110,6 +112,20 @@ tp_chat_async_cb (TpChannel *proxy,
 	}
 }
 
+static void
+create_conference_cb (GObject *source,
+		      GAsyncResult *result,
+		      gpointer user_data)
+{
+	GError *error = NULL;
+
+	if (!tp_account_channel_request_create_channel_finish (
+			TP_ACCOUNT_CHANNEL_REQUEST (source), result, &error)) {
+		DEBUG ("Failed to create conference channel: %s", error->message);
+		g_error_free (error);
+	}
+}
+
 static void
 tp_chat_add (EmpathyContactList *list,
 	     EmpathyContact     *contact,
@@ -129,14 +145,12 @@ tp_chat_add (EmpathyContactList *list,
 		tp_cli_channel_interface_group_call_add_members (priv->channel,
 			-1, &handles, NULL, NULL, NULL, NULL, NULL);
 	} else if (priv->can_upgrade_to_muc) {
-		EmpathyDispatcher *dispatcher;
+		TpAccountChannelRequest *req;
 		GHashTable        *props;
 		const char        *object_path;
 		GPtrArray          channels = { (gpointer *) &object_path, 1 };
 		const char        *invitees[2] = { NULL, };
 
-		dispatcher = empathy_dispatcher_dup_singleton ();
-
 		invitees[0] = empathy_contact_get_id (contact);
 		object_path = tp_proxy_get_object_path (priv->channel);
 
@@ -152,13 +166,16 @@ tp_chat_add (EmpathyContactList *list,
 		    /* FIXME: InvitationMessage ? */
 		    NULL);
 
-		/* Although this is a MUC, it's anonymous, so CreateChannel is
-		 * valid.
-		 * props now belongs to EmpathyDispatcher, don't free it */
-		empathy_dispatcher_create_channel (dispatcher, priv->connection,
-				props, EMPATHY_DISPATCHER_NON_USER_ACTION, NULL, NULL);
+		req = tp_account_channel_request_new (priv->account, props,
+			TP_USER_ACTION_TIME_NOT_USER_ACTION);
 
-		g_object_unref (dispatcher);
+		/* Although this is a MUC, it's anonymous, so CreateChannel is
+		 * valid. */
+		tp_account_channel_request_create_channel_async (req, NULL, NULL,
+			create_conference_cb, NULL);
+
+		g_object_unref (req);
+		g_hash_table_unref (props);
 	} else {
 		g_warning ("Cannot add to this channel");
 	}
@@ -762,6 +779,8 @@ tp_chat_dispose (GObject *object)
 
 	priv->dispose_has_run = TRUE;
 
+	tp_clear_object (&priv->account);
+
 	if (priv->connection != NULL)
 		g_object_unref (priv->connection);
 	priv->connection = NULL;
@@ -1245,7 +1264,7 @@ tp_chat_constructor (GType                  type,
 
 	priv = GET_PRIV (chat);
 
-	priv->connection = g_object_ref (tp_channel_borrow_connection (priv->channel));
+	priv->connection = g_object_ref (tp_account_get_connection (priv->account));
 	tp_g_signal_connect_object (priv->channel, "invalidated",
 			  G_CALLBACK (tp_chat_invalidated_cb),
 			  chat, 0);
@@ -1353,6 +1372,9 @@ tp_chat_get_property (GObject    *object,
 	EmpathyTpChatPriv *priv = GET_PRIV (object);
 
 	switch (param_id) {
+	case PROP_ACCOUNT:
+		g_value_set_object (value, priv->account);
+		break;
 	case PROP_CHANNEL:
 		g_value_set_object (value, priv->channel);
 		break;
@@ -1380,6 +1402,9 @@ tp_chat_set_property (GObject      *object,
 	EmpathyTpChatPriv *priv = GET_PRIV (object);
 
 	switch (param_id) {
+	case PROP_ACCOUNT:
+		priv->account = g_value_dup_object (value);
+		break;
 	case PROP_CHANNEL:
 		priv->channel = g_value_dup_object (value);
 		break;
@@ -1400,6 +1425,16 @@ empathy_tp_chat_class_init (EmpathyTpChatClass *klass)
 	object_class->get_property = tp_chat_get_property;
 	object_class->set_property = tp_chat_set_property;
 
+	g_object_class_install_property (object_class,
+					 PROP_ACCOUNT,
+					 g_param_spec_object ("account",
+							      "TpAccount",
+							      "the account associated with the chat",
+							      TP_TYPE_ACCOUNT,
+							      G_PARAM_READWRITE |
+							      G_PARAM_CONSTRUCT_ONLY |
+							      G_PARAM_STATIC_STRINGS));
+
 	g_object_class_install_property (object_class,
 					 PROP_CHANNEL,
 					 g_param_spec_object ("channel",
@@ -1507,9 +1542,14 @@ tp_chat_iface_init (EmpathyContactListIface *iface)
 }
 
 EmpathyTpChat *
-empathy_tp_chat_new (TpChannel *channel)
+empathy_tp_chat_new (TpAccount *account,
+		     TpChannel *channel)
 {
+	g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
+	g_return_val_if_fail (TP_IS_CHANNEL (channel), NULL);
+
 	return g_object_new (EMPATHY_TYPE_TP_CHAT,
+			     "account", account,
 			     "channel", channel,
 			     NULL);
 }
@@ -1564,6 +1604,16 @@ empathy_tp_chat_get_channel (EmpathyTpChat *chat)
 	return priv->channel;
 }
 
+TpAccount *
+empathy_tp_chat_get_account (EmpathyTpChat *chat)
+{
+	EmpathyTpChatPriv *priv = GET_PRIV (chat);
+
+	g_return_val_if_fail (EMPATHY_IS_TP_CHAT (chat), NULL);
+
+	return priv->account;
+}
+
 TpConnection *
 empathy_tp_chat_get_connection (EmpathyTpChat *chat)
 {
@@ -1573,7 +1623,6 @@ empathy_tp_chat_get_connection (EmpathyTpChat *chat)
 
 	return tp_channel_borrow_connection (priv->channel);
 }
-
 gboolean
 empathy_tp_chat_is_ready (EmpathyTpChat *chat)
 {
