@@ -32,6 +32,9 @@
 
 #include <libxml/uri.h>
 
+#include <folks/folks.h>
+#include <folks/folks-telepathy.h>
+
 #include <telepathy-glib/account-manager.h>
 #include <telepathy-glib/connection.h>
 #include <telepathy-glib/channel.h>
@@ -40,10 +43,11 @@
 
 #include "empathy-utils.h"
 #include "empathy-contact-manager.h"
+#include "empathy-individual-manager.h"
 #include "empathy-dispatcher.h"
-#include "empathy-dispatch-operation.h"
 #include "empathy-idle.h"
 #include "empathy-tp-call.h"
+#include "empathy-tp-contact-factory.h"
 
 #include <extensions/extensions.h>
 
@@ -52,7 +56,7 @@
 
 /* Translation between presence types and string */
 static struct {
-	gchar *name;
+	const gchar *name;
 	TpConnectionPresenceType type;
 } presence_types[] = {
 	{ "available", TP_CONNECTION_PRESENCE_TYPE_AVAILABLE },
@@ -249,6 +253,7 @@ empathy_presence_get_default_message (TpConnectionPresenceType presence)
 		return _("Unknown");
 	case TP_CONNECTION_PRESENCE_TYPE_UNSET:
 	case TP_CONNECTION_PRESENCE_TYPE_ERROR:
+	default:
 		return NULL;
 	}
 
@@ -279,7 +284,7 @@ empathy_presence_from_str (const gchar *str)
 	return TP_CONNECTION_PRESENCE_TYPE_UNSET;
 }
 
-const gchar *
+static const gchar *
 empathy_status_reason_get_default_message (TpConnectionStatusReason reason)
 {
 	switch (reason) {
@@ -316,6 +321,100 @@ empathy_status_reason_get_default_message (TpConnectionStatusReason reason)
 	}
 }
 
+static GHashTable *
+create_errors_to_message_hash (void)
+{
+	GHashTable *errors;
+
+	errors = g_hash_table_new (g_str_hash, g_str_equal);
+	g_hash_table_insert (errors, TP_ERROR_STR_NETWORK_ERROR, _("Network error"));
+	g_hash_table_insert (errors, TP_ERROR_STR_AUTHENTICATION_FAILED,
+		_("Authentication failed"));
+	g_hash_table_insert (errors, TP_ERROR_STR_ENCRYPTION_ERROR,
+		_("Encryption error"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_NOT_PROVIDED,
+		_("Certificate not provided"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_UNTRUSTED,
+		_("Certificate untrusted"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_EXPIRED,
+		_("Certificate expired"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_NOT_ACTIVATED,
+		_("Certificate not activated"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_HOSTNAME_MISMATCH,
+		_("Certificate hostname mismatch"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_FINGERPRINT_MISMATCH,
+		_("Certificate fingerprint mismatch"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_SELF_SIGNED,
+		_("Certificate self-signed"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CANCELLED,
+		_("Status is set to offline"));
+	g_hash_table_insert (errors, TP_ERROR_STR_ENCRYPTION_NOT_AVAILABLE,
+		_("Encryption is not available"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_INVALID,
+		_("Certificate is invalid"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CONNECTION_REFUSED,
+		_("Connection has been refused"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CONNECTION_FAILED,
+		_("Connection can't be established"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CONNECTION_LOST,
+		_("Connection has been lost"));
+	g_hash_table_insert (errors, TP_ERROR_STR_ALREADY_CONNECTED,
+		_("This resource is already connected to the server"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CONNECTION_REPLACED,
+		_("Connection has been replaced by a new connection using the "
+		"same resource"));
+	g_hash_table_insert (errors, TP_ERROR_STR_REGISTRATION_EXISTS,
+		_("The account already exists on the server"));
+	g_hash_table_insert (errors, TP_ERROR_STR_SERVICE_BUSY,
+		_("Server is currently too busy to handle the connection"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_REVOKED,
+		_("Certificate has been revoked"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_INSECURE,
+		_("Certificate uses an insecure cipher algorithm or is "
+		"cryptographically weak"));
+	g_hash_table_insert (errors, TP_ERROR_STR_CERT_LIMIT_EXCEEDED,
+		_("The length of the server certificate, or the depth of the "
+		"server certificate chain exceed the limits imposed by the "
+		"crypto library"));
+
+	return errors;
+}
+
+static const gchar *
+empathy_dbus_error_name_get_default_message  (const gchar *error)
+{
+	static GHashTable *errors_to_message = NULL;
+
+	if (error == NULL)
+		return NULL;
+
+	if (G_UNLIKELY (errors_to_message == NULL)) {
+		errors_to_message = create_errors_to_message_hash ();
+	}
+
+	return g_hash_table_lookup (errors_to_message, error);
+}
+
+const gchar *
+empathy_account_get_error_message (TpAccount *account)
+{
+	const gchar *dbus_error;
+	const gchar *message;
+	TpConnectionStatusReason reason;
+
+	dbus_error = tp_account_get_detailed_error (account, NULL);
+	message = empathy_dbus_error_name_get_default_message (dbus_error);
+	if (message != NULL)
+		return message;
+
+	DEBUG ("Don't understand error '%s'; fallback to the status reason (%u)",
+		dbus_error, reason);
+
+	tp_account_get_connection_status (account, &reason);
+
+	return empathy_status_reason_get_default_message (reason);
+}
+
 gchar *
 empathy_file_lookup (const gchar *filename, const gchar *subdir)
 {
@@ -553,8 +652,79 @@ empathy_connect_new_account (TpAccount *account,
         g_free (message);
         break;
 
+       case TP_CONNECTION_PRESENCE_TYPE_AVAILABLE:
+       case TP_CONNECTION_PRESENCE_TYPE_AWAY:
+       case TP_CONNECTION_PRESENCE_TYPE_EXTENDED_AWAY:
+       case TP_CONNECTION_PRESENCE_TYPE_HIDDEN:
+       case TP_CONNECTION_PRESENCE_TYPE_BUSY:
+       case TP_CONNECTION_PRESENCE_TYPE_ERROR:
        default:
         /* do nothing if the presence is not offline */
         break;
     }
 }
+
+/* Translate Folks' general presence type to the Tp presence type */
+TpConnectionPresenceType
+empathy_folks_presence_type_to_tp (FolksPresenceType type)
+{
+  return (TpConnectionPresenceType) type;
+}
+
+/* Returns TRUE if the given Individual contains a TpContact */
+gboolean
+empathy_folks_individual_contains_contact (FolksIndividual *individual)
+{
+  GList *personas, *l;
+
+  g_return_val_if_fail (FOLKS_IS_INDIVIDUAL (individual), FALSE);
+
+  personas = folks_individual_get_personas (individual);
+  for (l = personas; l != NULL; l = l->next)
+    {
+      if (TPF_IS_PERSONA (l->data))
+        return (tpf_persona_get_contact (TPF_PERSONA (l->data)) != NULL);
+    }
+
+  return FALSE;
+}
+
+/* TODO: this needs to be eliminated (and replaced in some cases with user
+ * prompts) when we break the assumption that FolksIndividuals are 1:1 with
+ * TpContacts */
+
+/* Retrieve the EmpathyContact corresponding to the first TpContact contained
+ * within the given Individual. Note that this is a temporary convenience. See
+ * the TODO above. */
+EmpathyContact *
+empathy_contact_dup_from_folks_individual (FolksIndividual *individual)
+{
+  GList *personas, *l;
+  EmpathyContact *contact = NULL;
+
+  g_return_val_if_fail (FOLKS_IS_INDIVIDUAL (individual), NULL);
+
+  personas = folks_individual_get_personas (individual);
+  for (l = personas; (l != NULL) && (contact == NULL); l = l->next)
+    {
+      TpfPersona *persona = l->data;
+
+      if (TPF_IS_PERSONA (persona))
+        {
+          TpContact *tp_contact;
+
+          tp_contact = tpf_persona_get_contact (persona);
+          contact = empathy_contact_dup_from_tp_contact (tp_contact);
+          empathy_contact_set_persona (contact, FOLKS_PERSONA (persona));
+        }
+    }
+
+  return contact;
+}
+
+TpChannelGroupChangeReason
+tp_chanel_group_change_reason_from_folks_groups_change_reason (
+    FolksGroupsChangeReason reason)
+{
+  return (TpChannelGroupChangeReason) reason;
+}
